import fastcomtec_api
import time 
import fastcomtec_plotting


########################################################
### Basics
########################################################
def load_dll():
    print("--- Load Dll ---")
    device = fastcomtec_api.FastComTec()
    print(device.get_acq_status())

def start_halt_erase():
    print("--- Start Halt Erase ---")
    device = fastcomtec_api.FastComTec()
    device.erase_measruement()
    device.start_measurement()
    print(device.get_acq_status())
    print()
    time.sleep(5)
    device.halt_measurement()
    print(device.get_acq_status())
    print()

def start_halt_wo_erase():
    print("--- Start Halt wo Erase ---")
    device = fastcomtec_api.FastComTec()
    print(device.get_acq_status())
    print()
    device.start_measurement()
    time.sleep(5)
    device.halt_measurement()
    print(device.get_acq_status())
    print()

def load_cfg():
    device = fastcomtec_api.FastComTec()
    device.load_config("C:/Users/admin/benjamin_code/FastComTec_self/configs/ExampleMeasurement1_config.mpa")
########################################################
### Fastcomtec Types
########################################################
def test_get_data():
    device = fastcomtec_api.FastComTec()
    device.start_measurement()
    data = device.get_acq_data()
    device.halt_measurement()
    print(data)

def get_fastcomtec_types():
    print("--- FastComTec types ----")
    device = fastcomtec_api.FastComTec()
    print("--- AcqSettings ---")
    print(device.get_acq_settings())
    print("--- AcqStatus ---")
    print(device.get_acq_status())
    print("--- BoardSettings ---")
    print(device.get_board_settings())
########################################################
### Example measurements
########################################################
def two_channel_measurement():   
    device = fastcomtec_api.FastComTec()
    device.load_config("C:/Users/admin/benjamin_code/FastComTec_self/configs/TwoChannelMeasurement_config.mpa")
    device.erase_measruement()
    device._send_dll_command("MC_A")
    device.start_measurement()
    time.sleep(1)
    device.halt_measurement()
    device.save_config_with_data("C:/Users/admin/benjamin_code/FastComTec_self/measurements/TwoChannelMeasurement.mpa")
    fastcomtec_api.separate_config_and_data_per_channel("C:/Users/admin/benjamin_code/FastComTec_self/measurements/TwoChannelMeasurement.mpa")

def example_measurement_1():
    device = fastcomtec_api.FastComTec()
    device.load_config("C:/Users/admin/benjamin_code/FastComTec_self/configs/ExampleMeasurement1_config.mpa")
    device.erase_measruement()
    # device._send_dll_command("MC_A")
    device.start_measurement()
    time.sleep(1)
    device.halt_measurement()
    output_file = "C:/Users/admin/benjamin_code/FastComTec_self/test_example.mpa"
    device.save_config_with_data(output_file)
    # device.save_config_and_data_seperately("C:/Users/admin/benjamin_code/FastComTec_self/test_example")
    fastcomtec_api.separate_config_and_data_per_channel(output_file)

def load_cfg_and_perform_measurement(config_path_full: str, output_path_full: str, measurement_time: float):
    device = fastcomtec_api.FastComTec()
    device.load_config(config_path_full)
    device.erase_measruement()
    # device._send_dll_command("MC_A")
    device.start_measurement()
    time.sleep(measurement_time)
    device.halt_measurement()
    device.save_config_with_data(output_path_full)
    fastcomtec_api.separate_config_and_data_per_channel(output_path_full)

########################################################
### Histogram plotting
########################################################
def print_data():
    fastcomtec_plotting.plot_raw_histogram("test_example_config.mpa", "test_example_data.mpa")
    fastcomtec_plotting.plot_raw_histograms("test_example_config.mpa", "test_example_data_TDAT0.mpa", "test_example_data_TDAT1.mpa") 

def safe_config():
    device = fastcomtec_api.FastComTec()
    device.save_config()

def custom_measurement():
    load_cfg_and_perform_measurement(
        config_path_full="C:/Users/admin/benjamin_code/FastComTec_self/configs/test.mpa",
        output_path_full="C:/Users/admin/benjamin_code/FastComTec_self/measurements/TwoChannelMeasurement.mpa",
        measurement_time=1
    )

def run_tests():
    device = fastcomtec_api.FastComTec()
    device._send_dll_command("bitshift=32")
    device.save_config()
run_tests()
